@@ -2,7 +2,7 @@ import os
 from typing import Any, cast
 
 from mongoengine import Document, connect
-from mongoengine.fields import IntField, StringField
+from mongoengine.fields import StringField
 
 
 class TranscodeItem(Document):
@@ -15,8 +15,6 @@ class TranscodeItem(Document):
     video_params = StringField(required=False)
     audio_params = StringField(required=False)
 
-    content_id = IntField(required=False)
-
 
 class TranscodeQueue:
     def __init__(self) -> None:
@@ -33,14 +31,12 @@ class TranscodeQueue:
         languages: str | None = None,
         video_params: str | None = None,
         audio_params: str | None = None,
-        content_id: int | None = None,
     ) -> None:
         TranscodeItem(
             path=path,
             languages=languages,
             video_params=video_params,
             audio_params=audio_params,
-            content_id=content_id,
         ).save()
 
     def get_one(self) -> TranscodeItem | None:
